// Webpack use JS as entry point, this js file is just here to tell Webpack which which css files it should use
require('./styles/index.scss');
/*
require('./styles/overrides.scss');
require('./styles/fonts.css');
require('./styles/fa.min.css'); // FIXME(chab) we should not have 2 fonts
require('./styles/main.scss');*/
