// General app layout

//  -       NAVBAR        -
//  *                     *
//  * -CURRENT CONTENT    *
//  *                     *
//  -       FOOTER        -

body, html, .body {
  background: $grey-lightest !important;
}

.global-banner {
  height: $global-banner-height;
}

.navbar {
  height: $navbar-height;
}

.footer {
  padding: 3rem 0 3rem 0;
  background: $secondary-dark;
  color: #fff;
}

.footer a {
  color: $blue-light;
}

.footer li a {
  display: inline-block;
  margin-top: 0.5rem;
}

.footer a:hover {
  color: $grey;
}

.footer .label {
  color: #fff;
}

.footer .container > .columns .column:last-child {
  text-align: center;
  font-size: 0.85rem;
}

.footer .container > .columns .column:last-child .columns {
  margin-bottom: 0;
}

.footer .columns img {
  max-width: 100%;
  max-height: 75px;
}

@media screen and (max-width: ($desktop - 1px)) {
  .global-banner {
    height: auto;
    font-size: $size-7;
  }
}

@media screen and (max-width: ($tablet - 1px)) {
}
